pub enum NameContext {
Input(Span),
Output(Span),
Decl(Span),
Call(Span),
ScatterVariable(Span),
}Expand description
Represents the context of a name in a scope.
Variants
Input(Span)
The name was introduced by an task or workflow input.
Output(Span)
The name was introduced by an task or workflow output.
Decl(Span)
The name was introduced by a private declaration.
Call(Span)
The name was introduced by a workflow call statement.
ScatterVariable(Span)
The name was introduced by a variable in workflow scatter statement.
Implementations