Module document

Module document 

Representation of analyzed WDL documents.

Modules

v1
Conversion of a V1 AST to an analyzed document.

Structs

Document
Represents an analyzed WDL document.
Enum
Represents an enum in a document.
Input
Represents a task or workflow input.
Name
Represents information about a name in a scope.
Namespace
A successfully resolved namespace introduced by an import.
Output
Represents a task or workflow output.
Scope
Represents a scope in a WDL document.
ScopeIndex
Represents an index of a scope in a collection of scopes.
ScopeRef
Represents a reference to a scope.
ScopeUnion
A scope union takes the union of names within a number of given scopes and computes a set of common output names for a presumed parent scope. This is useful when calculating common elements from, for example, an if statement within a workflow.
Struct
Represents a struct in a document.
Task
Represents a task in a document.
Workflow
Represents a workflow in a document.

Enums

Callable
A callable item.

Constants

TASK_VAR_NAME
The task variable name available in task command sections and outputs in WDL 1.2.