MaybeImported

Enum MaybeImported 

pub enum MaybeImported<Local, Imported> {
    Local(Local),
    Imported(Imported),
}
An item in the current document’s scope.

Variants



Local(Local)

The item is locally defined.



Imported(Imported)

The item was imported from another document.

Implementations

Source

impl<L, I> MaybeImported<L, I>

pub fn is_imported(&self) -> bool

Returns true if the item was imported.

pub fn expect_imported(self) -> I

Returns the imported item.

Panics

This will panic if the item was locally defined.

pub fn expect_local(self) -> L

Returns the contained local item.

Panics

This will panic if the item was imported.

Source

impl<'a> MaybeImported<&'a Workflow, &'a ImportedWorkflow>

pub fn name(&self) -> &'a str

Gets the name of the workflow.

pub fn name_span(&self) -> Span

Gets the span of the name.

pub fn inputs(&self) -> Arc<IndexMap<String, Input>> ⓘ

The inputs of the workflow.

pub fn outputs(&self) -> Arc<IndexMap<String, Output>> ⓘ

The outputs of the workflow.

pub fn source(&self) -> Option<Arc<Url>>

Gets the source of the workflow, if it was imported.

Source

impl<'a> MaybeImported<&'a Task, &'a ImportedTask>

pub fn name(&self) -> &'a str

Gets the name of the task.

pub fn name_span(&self) -> Span

Gets the span of the name.

pub fn inputs(&self) -> Arc<IndexMap<String, Input>> ⓘ

The inputs of the task.

pub fn outputs(&self) -> Arc<IndexMap<String, Output>> ⓘ

The outputs of the task.

pub fn source(&self) -> Option<Arc<Url>>

Gets the source of the task, if it was imported.

Source

impl<'a> MaybeImported<&'a Struct, &'a ImportedStruct>

pub fn name(&self) -> &'a str

Gets the name of the struct.

pub fn name_span(&self) -> Span

Gets the span of the name.

pub fn ty(&self) -> Option<&'a Type>

Gets the type of the struct, if it was computed.

pub fn source(&self) -> Option<Arc<Url>>

Gets the source of the struct, if it was imported.

pub fn definition(&self) -> StructDefinition

Reconstructs the AST definition from the stored green node.

pub fn offset(&self) -> usize

Gets the offset of the struct in the source document’s CST.

pub fn node(&self) -> &'a GreenNode

Gets the node of the struct.

Source

impl<'a> MaybeImported<&'a Enum, &'a ImportedEnum>

pub fn name(&self) -> &'a str

Gets the name of the enum.

pub fn name_span(&self) -> Span

Gets the span of the name.

pub fn ty(&self) -> Option<&'a Type>

Gets the type of the enum, if it was computed.

pub fn source(&self) -> Option<Arc<Url>>

Gets the source of the enum if it was imported.

pub fn definition(&self) -> EnumDefinition

Reconstructs the AST definition from the stored green node.

pub fn offset(&self) -> usize

Gets the offset of the enum.

pub fn node(&self) -> &'a GreenNode

Gets the node of the enum.

Source

impl<'a> MaybeImported<CachedItemRef<'a>, ImportedItem<'a>>

pub fn signature_hash(&self) -> Option<[u8; 32]>

Get the [SignatureHash] of the item, if it was locally defined.