StructRef

Type Alias StructRef 

pub type StructRef<'a> = MaybeImported<&'a Struct, &'a ImportedStruct>;
A reference to a struct in the document’s scope.

Aliased Type

pub enum StructRef<'a> {
    Local(&'a Struct),
    Imported(&'a ImportedStruct),
}

Variants



Local(&'a Struct)

The item is locally defined.



Imported(&'a ImportedStruct)

The item was imported from another document.

Implementations

Source

impl<'a> StructRef<'a>

pub fn name(&self) -> &'a str

Gets the name of the struct.

pub fn name_span(&self) -> Span

Gets the span of the name.

pub fn ty(&self) -> Option<&'a Type>

Gets the type of the struct, if it was computed.

pub fn source(&self) -> Option<Arc<Url>>

Gets the source of the struct, if it was imported.

pub fn definition(&self) -> StructDefinition

Reconstructs the AST definition from the stored green node.

pub fn offset(&self) -> usize

Gets the offset of the struct in the source document’s CST.

pub fn node(&self) -> &'a GreenNode

Gets the node of the struct.