pub struct ImportedEnum {
pub local_name: String,
pub span: Span,
pub document: Document,
/* private fields */
}Expand description
An enum imported into scope.
Fields
local_name: StringThe aliased name of the enum in the dependent document.
span: SpanThe span of the import statement.
document: DocumentThe source document that defines the enum.
Implementations
Sourceimpl ImportedEnum
impl ImportedEnum
Sourcepub fn definition(&self) -> EnumDefinition
pub fn definition(&self) -> EnumDefinition
Reconstructs the AST definition from the stored green node.
This provides access to choice expressions and other AST details.