pub struct ImportedTask {
pub local_name: String,
pub name: String,
pub span: Span,
pub document: Document,
pub inputs: Arc<IndexMap<String, Input>>,
pub outputs: Arc<IndexMap<String, Output>>,
}Expand description
A task imported into scope by a wildcard or selected-member import.
Fields
local_name: StringThe aliased name of the task in the dependent document.
name: StringThe task name in the source document.
span: SpanThe span of the import statement that introduced this task.
document: DocumentThe source document that defines the task.
inputs: Arc<IndexMap<String, Input>>The inputs of the task.
outputs: Arc<IndexMap<String, Output>>The outputs of the task.
Implementations