pub struct ImportedWorkflow {
pub local_name: String,
pub name: String,
pub span: Span,
pub document: Document,
pub inputs: Arc<IndexMap<String, Input>>,
pub outputs: Arc<IndexMap<String, Output>>,
}Expand description
A workflow imported into scope by a wildcard or selected-member import.
Fields
local_name: StringThe aliased name of the workflow in the dependent document.
name: StringThe workflow name in the source document.
span: SpanThe span of the import statement.
document: DocumentThe source document that defines the task.
inputs: Arc<IndexMap<String, Input>>The inputs of the workflow.
outputs: Arc<IndexMap<String, Output>>The outputs of the workflow.
Implementations