WorkflowGraphNode

Enum WorkflowGraphNode 

pub enum WorkflowGraphNode<N: TreeNode = SyntaxNode> {
    Input(Decl<N>),
    Decl(Decl<N>),
    Output(Decl<N>),
    Conditional(ConditionalStatement<N>, NodeIndex),
    ConditionalClause(ConditionalStatementClause<N>, NodeIndex),
    Scatter(ScatterStatement<N>, NodeIndex),
    Call(CallStatement<N>),
    ExitConditional(ConditionalStatement<N>),
    ExitScatter(ScatterStatement<N>),
}
Represents a node in an workflow evaluation graph.

Variants



Input(Decl<N>)

The node is an input.



Decl(Decl<N>)

The node is a private decl.



Output(Decl<N>)

The node is an output decl.



Conditional(ConditionalStatement<N>, NodeIndex)

The node is a conditional statement.

Stores the AST node along with the exit node index.



ConditionalClause(ConditionalStatementClause<N>, NodeIndex)

The node represents a specific clause within a conditional statement.

Stores the clause AST node and exit node index. This allows each clause to have its own subgraph.



Scatter(ScatterStatement<N>, NodeIndex)

The node is a scatter statement.

Stores the AST node along with the exit node index.



Call(CallStatement<N>)

The node is a call statement.



ExitConditional(ConditionalStatement<N>)

The node is an exit of a conditional statement.

This is a special node that is paired with each conditional statement node.

It is the point by which the conditional is being exited and the outputs of the statement are introduced into the parent scope.



ExitScatter(ScatterStatement<N>)

The node is an exit of a scatter statement.

This is a special node that is paired with each scatter statement node.

It is the point by which the scatter is being exited and the outputs of the statement are introduced into the parent scope.

Implementations

Source

impl<N: TreeNode> WorkflowGraphNode<N>

pub fn context(&self) -> Option<NameContext>

Gets the context of the name introduced by the node.

Returns None if the node did not introduce a name.

pub fn inner(&self) -> &N

Gets the inner node representation for the workflow graph node.