pub struct TaskGraphBuilder<N: TreeNode = SyntaxNode> { /* private fields */ }Expand description
A builder for task evaluation graphs.
Implementations
Sourceimpl<N: TreeNode> TaskGraphBuilder<N>
impl<N: TreeNode> TaskGraphBuilder<N>
Sourcepub fn build(
self,
version: SupportedVersion,
task: &TaskDefinition<N>,
diagnostics: &mut Diagnostics,
custom_type_present: impl Fn(&str) -> bool,
) -> DiGraph<TaskGraphNode<N>, bool>
pub fn build( self, version: SupportedVersion, task: &TaskDefinition<N>, diagnostics: &mut Diagnostics, custom_type_present: impl Fn(&str) -> bool, ) -> DiGraph<TaskGraphNode<N>, bool>
Builds a new task evaluation graph.
The nodes are TaskGraphNode and the edges represent a reverse
dependency relationship (A -> B => “node A is depended on by B”).
The edge data indicates whether or not the edge is an implicit edge between the node and the command section.
Commands implicitly depend on all inputs, environment variables, the requirements section, the runtime section, and the hints section.
Outputs implicitly depend on the command section.