pub struct AppliedEdit {
pub range: Range<usize>,
pub replacement_length: usize,
}Expand description
Represents an edit to a document’s source after it has been applied.
Fields
range: Range<usize>The range in the old string that was replaced.
replacement_length: usizeThe length of the new text that replaced it.