pub struct Diagnostics { /* private fields */ }Expand description
Represents a collection of validation diagnostics.
Validation visitors receive a diagnostics collection during visitation of the AST.
Implementations
Sourceimpl Diagnostics
impl Diagnostics
Sourcepub fn add(&mut self, diagnostic: Diagnostic)
pub fn add(&mut self, diagnostic: Diagnostic)
Adds a diagnostic to the collection.
NOTE: This is intended for diagnostics that cannot be suppressed.
Otherwise, Diagnostics::exceptable_add() should be used.
Sourcepub fn add_exceptions(
&mut self,
exceptions: impl IntoIterator<Item = ExceptRule>,
)
pub fn add_exceptions( &mut self, exceptions: impl IntoIterator<Item = ExceptRule>, )
Adds rule exceptions to the collection.
Sourcepub fn exceptable_add<N: TreeNode + Exceptable>(
&mut self,
diagnostic: Diagnostic,
element: &N,
exceptable_nodes: &Option<&'static [SyntaxKind]>,
)
pub fn exceptable_add<N: TreeNode + Exceptable>( &mut self, diagnostic: Diagnostic, element: &N, exceptable_nodes: &Option<&'static [SyntaxKind]>, )
Adds a diagnostic to the collection, unless the diagnostic is for an element that has an exception for the given rule.
If the diagnostic does not have a rule, the diagnostic is always added.
Sourcepub fn iter(&self) -> Iter<'_, Diagnostic>
pub fn iter(&self) -> Iter<'_, Diagnostic>
Iterate the diagnostics emitted so far.