pub struct Example {
pub negative: LabeledSnippet,
pub revised: Option<LabeledSnippet>,
}Expand description
A lint rule example.
Fields
negative: LabeledSnippetA snippet that will trigger the target lint rule.
revised: Option<LabeledSnippet>A revision of the negative snippet that will no longer trigger the rule.