Exceptable

Trait Exceptable 

pub trait Exceptable {
    // Provided methods
    fn rule_exceptions(&self) -> HashSet<String> { ... }
    fn is_rule_excepted(&self, _id: &str) -> bool { ... }
}
An extension trait for syntax nodes.

Provided Methods

fn rule_exceptions(&self) -> HashSet<String>

Gets the AST node’s rule exceptions set.

The set is the comma-delimited list of rule identifiers that follows a #@ except: comment.

fn is_rule_excepted(&self, _id: &str) -> bool

Determines if a given rule id is excepted for the syntax node.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Exceptable for SyntaxNode

Implementors