pub type RuleMap = HashMap<String, Option<&'static [SyntaxKind]>>;Expand description
A mapping of lint rule names to their exceptable nodes.
Aliased Type
pub struct RuleMap { /* private fields */ }pub type RuleMap = HashMap<String, Option<&'static [SyntaxKind]>>;A mapping of lint rule names to their exceptable nodes.
pub struct RuleMap { /* private fields */ }