CompoundType

Enum CompoundType 

pub enum CompoundType {
    Array(ArrayType),
    Pair(PairType),
    Map(MapType),
    Custom(CustomType),
}
Represents a compound type definition.

Variants



Array(ArrayType)

The type is an Array.



Pair(PairType)

The type is a Pair.



Map(MapType)

The type is a Map.



Custom(CustomType)

The type is a custom type (a struct or enum).

Implementations

Source

impl CompoundType

pub fn as_array(&self) -> Option<&ArrayType>

Converts the compound type to an array type.

Returns None if the compound type is not an array type.

pub fn as_pair(&self) -> Option<&PairType>

Converts the compound type to a pair type.

Returns None if the compound type is not a pair type.

pub fn as_map(&self) -> Option<&MapType>

Converts the compound type to a map type.

Returns None if the compound type is not a map type.

pub fn as_struct(&self) -> Option<&StructType>

Converts the compound type to a struct type.

Returns None if the compound type is not a struct type.

pub fn as_enum(&self) -> Option<&EnumType>

Converts the compound type to an enum type.

Returns None if the compound type is not an enum type.

pub fn as_custom(&self) -> Option<&CustomType>

Converts the compound type to a custom type.

Returns None if the compound type is not a custom type.