pub struct TypeNameRef(/* private fields */);Expand description
Represents a reference to a custom type (struct or enum).
Implementations
Sourceimpl TypeNameRef
impl TypeNameRef
Sourcepub fn new(name: impl Into<String>, ty: CustomType) -> Self
pub fn new(name: impl Into<String>, ty: CustomType) -> Self
Constructs a new TypeNameRef.
Sourcepub fn ty(&self) -> &CustomType
pub fn ty(&self) -> &CustomType
Gets the referenced custom type.
Sourcepub fn as_struct(&self) -> Option<&StructType>
pub fn as_struct(&self) -> Option<&StructType>
Converts the referenced custom type to a struct type.
Returns None if the referenced custom type is not a struct.