Exceptable

Trait Exceptable 

pub trait Exceptable {
    // Provided methods
    fn rule_exceptions(&self) -> HashSet<String> { ... }
    fn is_rule_excepted(&self, _id: &str) -> bool { ... }
}
An extension trait for syntax nodes.

Provided Methods

fn rule_exceptions(&self) -> HashSet<String>

Gets the AST node’s rule exceptions set.

The set is the comma-delimited list of rule identifiers that follows a #@ except: comment.

fn is_rule_excepted(&self, _id: &str) -> bool

Determines if a given rule id is excepted for the syntax node.

Implementations on Foreign Types

Source

impl Exceptable for SyntaxNode

Implementors